"""Transcode MP4 in the `clips/` directory to OGG in `sounds/`."""

import subprocess
from pathlib import Path

CLIPS_DIRECTORY = Path(__file__).parent / 'clips'
SOUND_DIRECTORY = Path(__file__).parent / 'sounds'

def transcode(clip_file, sound_file):
    """Call FFMPEG binary to transcode MP4 to OGG."""
    subprocess.call(["ffmpeg", "-i", clip_file,  "-vn",  "-acodec", "libvorbis",  sound_file, "-y"])

def main():
    """Transcode MP4 in the `clips/` directory to OGG in `sounds/`."""
    for clip in CLIPS_DIRECTORY.rglob('**/*.mp4'):
        print(clip)
        transcode(clip, SOUND_DIRECTORY / f"{clip.stem}.ogg")

if __name__ == "__main__":
    main()
